@@ -51,7 +51,7 @@ class FLModel(fedtreeBase):
     def __init__(self, n_parties, partition, alpha, n_hori, n_verti, mode, partition_mode, privacy_tech, propose_split,
                  merge_histogram, variance, privacy_budget, max_depth, n_trees, min_child_weight, lambda_ft, gamma,
                  column_sampling_rate, verbose, n_parallel_trees, learning_rate, objective, num_class, n_device, max_num_bin,
-                 seed, ins_bagging_fraction, reorder_label, bagging, tree_method):
+                 seed, ins_bagging_fraction, reorder_label, bagging, constant_h, tree_method):
         # Federated Learning related variables
         self.n_parties = n_parties
         self.partition = partition
@@ -88,6 +88,7 @@ class FLModel(fedtreeBase):
         self.group_label = None
         self.bagging = bagging
         self.reorder_label = reorder_label
+        self.constant_h = constant_h
 
     def fit(self, X, y, groups=None):
         if self.model is not None:
@@ -130,7 +131,7 @@ class FLModel(fedtreeBase):
                     self.partition_mode.encode('utf-8'), self.privacy_tech.encode('utf-8'), self.propose_split.encode('utf-8'), self.merge_histogram.encode('utf-8'), c_float(self.variance), c_float(self.privacy_budget),
                     self.max_depth, self.n_trees, c_float(self.min_child_weight), c_float(self.lambda_ft), c_float(self.gamma), c_float(self.column_sampling_rate),
                     self.verbose, self.bagging, self.n_parallel_trees, c_float(self.learning_rate), self.objective.encode('utf-8'), n_class, self.n_device, self.max_num_bin,
-                    self.seed, c_float(self.ins_bagging_fraction), self.reorder_label,
+                    self.seed, c_float(self.ins_bagging_fraction), self.reorder_label, c_float(self.constant_h),
                     X.shape[0], data, indptr, indices, label, self.tree_method, byref(self.model), tree_per_iter_ptr, group_label,
                     in_groups, num_groups)
         self.num_class = n_class[0]
@@ -356,8 +357,8 @@ class FLClassifier(FLModel, fedtreeClassifierBase):
                  partition_mode="horizontal", privacy_tech="none", propose_split="server", merge_histogram="server",
                  variance=200, privacy_budget=10, max_depth=6, n_trees=40, min_child_weight=1, lambda_ft=1,
                  gamma=1, column_sampling_rate=1, verbose=1, n_parallel_trees=1, learning_rate=1, objective="binary:logistic",
-                 num_class=1, n_device=1, max_num_bin=255, seed=36, ins_bagging_fraction=1.0, reorder_label=1, bagging = 0,
-                 tree_method="auto"):
+                 num_class=1, n_device=1, max_num_bin=255, seed=36, ins_bagging_fraction=1.0, reorder_label=0, bagging = 0,
+                 constant_h = 0.0, tree_method="auto"):
         super().__init__(n_parties=n_parties, partition=partition, alpha=alpha, n_hori=n_hori, n_verti=n_verti,
                          mode=mode, partition_mode=partition_mode, privacy_tech=privacy_tech, propose_split=propose_split,
                          merge_histogram=merge_histogram, variance=variance, privacy_budget=privacy_budget, max_depth=max_depth,
@@ -365,7 +366,7 @@ class FLClassifier(FLModel, fedtreeClassifierBase):
                          column_sampling_rate=column_sampling_rate, verbose=verbose, n_parallel_trees=n_parallel_trees,
                          learning_rate=learning_rate, objective=objective, num_class=num_class, n_device=n_device,
                          max_num_bin=max_num_bin, seed=seed, ins_bagging_fraction=ins_bagging_fraction,
-                         reorder_label=reorder_label, bagging=bagging, tree_method=tree_method)
+                         reorder_label=reorder_label, bagging=bagging, constant_h=constant_h, tree_method=tree_method)
 
 class FLRegressor(FLModel, fedtreeRegressorBase):
     _impl = 'regressor'
@@ -374,7 +375,7 @@ class FLRegressor(FLModel, fedtreeRegressorBase):
                  variance=200, privacy_budget=10, max_depth=6, n_trees=40, min_child_weight=1, lambda_ft=1,
                  gamma=1, column_sampling_rate=1, verbose=1, n_parallel_trees=1, learning_rate=1, objective="reg:linear",
                  num_class=1, n_device=1, max_num_bin=255, seed=36, ins_bagging_fraction=1.0, reorder_label=0, bagging = 0,
-                 tree_method="auto"):
+                 constant_h = 0.0, tree_method="auto"):
         super().__init__(n_parties=n_parties, partition=partition, alpha=alpha, n_hori=n_hori, n_verti=n_verti,
                          mode=mode, partition_mode=partition_mode, privacy_tech=privacy_tech, propose_split=propose_split,
                          merge_histogram=merge_histogram, variance=variance, privacy_budget=privacy_budget, max_depth=max_depth,
@@ -382,4 +383,4 @@ class FLRegressor(FLModel, fedtreeRegressorBase):
                          column_sampling_rate=column_sampling_rate, verbose=verbose, n_parallel_trees=n_parallel_trees,
                          learning_rate=learning_rate, objective=objective, num_class=num_class, n_device=n_device,
                          max_num_bin=max_num_bin, seed=seed, ins_bagging_fraction=ins_bagging_fraction,
-                         reorder_label=reorder_label, bagging=bagging, tree_method=tree_method)
+                         reorder_label=reorder_label, bagging=bagging, constant_h=constant_h, tree_method=tree_method)
